@@ -364,27 +364,7 @@ class GameNode(object):
 class Game(GameNode):
     """
     The root node of a game with extra information such as headers and the
-    starting position.
-
-    By default the following 7 headers are provided in an ordered dictionary:
-
-    >>> game = chess.pgn.Game()
-    >>> game.headers["Event"]
-    '?'
-    >>> game.headers["Site"]
-    '?'
-    >>> game.headers["Date"]
-    '????.??.??'
-    >>> game.headers["Round"]
-    '?'
-    >>> game.headers["White"]
-    '?'
-    >>> game.headers["Black"]
-    '?'
-    >>> game.headers["Result"]
-    '*'
-
-    Also has all the other properties and methods of
+    starting position. Also has all the other properties and methods of
     :class:`~chess.pgn.GameNode`.
     """
 
@@ -633,6 +613,10 @@ class StringExporter(BaseVisitor):
     """
     Allows exporting a game as a string.
 
+    >>> import chess.pgn
+    >>>
+    >>> game = chess.pgn.Game()
+    >>>
     >>> exporter = chess.pgn.StringExporter(headers=True, variations=True, comments=True)
     >>> pgn_string = game.accept(exporter)
 
@@ -737,7 +721,11 @@ class FileExporter(StringExporter):
     There will always be a blank line after each game. Handling encodings is up
     to the caller.
 
-    >>> new_pgn = open("new.pgn", "w", encoding="utf-8")
+    >>> import chess.pgn
+    >>>
+    >>> game = chess.pgn.Game()
+    >>>
+    >>> new_pgn = open("/dev/null", "w", encoding="utf-8")
     >>> exporter = chess.pgn.FileExporter(new_pgn)
     >>> game.accept(exporter)
     """
@@ -771,18 +759,30 @@ def read_game(handle, Visitor=GameModelCreator):
     """
     Reads a game from a file opened in text mode.
 
+    >>> import chess.pgn
+    >>>
     >>> pgn = open("data/pgn/kasparov-deep-blue-1997.pgn")
+    >>>
     >>> first_game = chess.pgn.read_game(pgn)
     >>> second_game = chess.pgn.read_game(pgn)
     >>>
     >>> first_game.headers["Event"]
     'IBM Man-Machine, New York USA'
+    >>>
+    >>> # Iterate through all moves and play them on a board.
+    >>> board = first_game.board()
+    >>> for move in first_game.main_line():
+    ...     board.push(move)
+    ...
+    >>> board
+    Board('4r3/6P1/2p2P1k/1p6/pP2p1R1/P1B5/2P2K2/3r4 b - - 0 45')
 
     By using text mode the parser does not need to handle encodings. It is the
     callers responsibility to open the file with the correct encoding.
     PGN files are ASCII or UTF-8 most of the time. So the following should
     cover most relevant cases (ASCII, UTF-8, UTF-8 with BOM).
 
+    >>> # Python 3
     >>> pgn = open("data/pgn/kasparov-deep-blue-1997.pgn", encoding="utf-8-sig")
 
     Use :class:`~io.StringIO` to parse games from a string.
@@ -790,10 +790,10 @@ def read_game(handle, Visitor=GameModelCreator):
     >>> pgn_string = "1. e4 e5 2. Nf3 *"
     >>>
     >>> try:
-    >>>     from StringIO import StringIO  # Python 2
-    >>> except ImportError:
-    >>>     from io import StringIO  # Python 3
-    >>>
+    ...     from StringIO import StringIO  # Python 2
+    ... except ImportError:
+    ...     from io import StringIO  # Python 3
+    ...
     >>> pgn = StringIO(pgn_string)
     >>> game = chess.pgn.read_game(pgn)
 
@@ -973,7 +973,10 @@ def scan_headers(handle):
 
     This example scans for the first game with Kasparov as the white player.
 
-    >>> pgn = open("mega.pgn")
+    >>> import chess.pgn
+    >>>
+    >>> pgn = open("data/pgn/kasparov-deep-blue-1997.pgn")
+    >>>
     >>> for offset, headers in chess.pgn.scan_headers(pgn):
     ...     if "Kasparov" in headers["White"]:
     ...         kasparov_offset = offset
@@ -982,6 +985,7 @@ def scan_headers(handle):
     Then it can later be seeked an parsed.
 
     >>> pgn.seek(kasparov_offset)
+    0
     >>> game = chess.pgn.read_game(pgn)
 
     This also works nicely with generators, scanning lazily only when the next
