@@ -1657,8 +1657,12 @@ class Tablebases(object):
         loss. Mate can be forced but the position can be drawn due to the
         fifty-move rule.
 
+        >>> import chess
+        >>> import chess.syzygy
+        >>>
         >>> with chess.syzygy.open_tablebases("data/syzygy/regular") as tablebases:
-        ...     tablebases.probe_wdl(chess.Board("8/2K5/4B3/3N4/8/8/4k3/8 b - - 0 1"))
+        ...     board = chess.Board("8/2K5/4B3/3N4/8/8/4k3/8 b - - 0 1")
+        ...     print(tablebases.probe_wdl(board))
         ...
         -2
 
@@ -1840,8 +1844,12 @@ class Tablebases(object):
         Engines like Stockfish calculate themselves, checking with DTZ, but
         only play according to DTZ if they can not manage on their own.
 
+        >>> import chess
+        >>> import chess.syzygy
+        >>>
         >>> with chess.syzygy.open_tablebases("data/syzygy/regular") as tablebases:
-        ...     tablebases.probe_dtz(chess.Board("8/2K5/4B3/3N4/8/8/4k3/8 b - - 0 1"))
+        ...     board = chess.Board("8/2K5/4B3/3N4/8/8/4k3/8 b - - 0 1")
+        ...     print(tablebases.probe_dtz(board))
         ...
         -53
 
