@@ -23,6 +23,8 @@ from chess.engine import EngineStateException
 from chess.engine import MockProcess
 from chess.engine import PopenProcess
 from chess.engine import SpurProcess
+from chess.engine import Option
+from chess.engine import OptionMap
 from chess.engine import LOGGER
 from chess.engine import FUTURE_POLL_TIMEOUT
 from chess.engine import _popen_engine
@@ -142,6 +144,58 @@ class PostHandler(object):
         self.release()
 
 
+class FeatureMap(object):
+
+    def __init__(self):
+        # Populated with defaults to begin with
+        self._features = {
+                "ping" : 0, # TODO: Remove dependency of xboard module on ping
+                "setboard" : 0,
+                "playother" : 0,
+                "san" : 0,
+                "usermove" : 0,
+                "time" : 1,
+                "draw" : 1,
+                "sigint" : 1,
+                "sigterm" : 1,
+                "reuse" : 1,
+                "analyze" : 1,
+                "myname" : None,
+                "variants" : None,
+                "colors" : 1,
+                "ics" : 0,
+                "name" : None,
+                "pause" : 0,
+                "nps" : 1,
+                "debug" : 0,
+                "memory" : 0,
+                "smp" : 0,
+                "egt" : 0,
+                "option" : OptionMap(),
+                "done" : None
+                }
+
+    def _set_feature(self, key, value):
+        try:
+            value = int(value)
+        except ValueError:
+            pass
+
+        try:
+            self._features[key] = value
+        except KeyError:
+            LOGGER.exception("exception looking up feature")
+
+    def get(self, key):
+        try:
+            return self._features[key]
+        except KeyError:
+            LOGGER.exception("exception looking up feature")
+
+    def supports(self, key):
+        return self.get(key) == 1
+
+
 class Engine(object):
     def __init__(self, Executor=concurrent.futures.ThreadPoolExecutor):
         self.idle = True
@@ -155,9 +209,9 @@ class Engine(object):
 
         self.name = None
         self.author = None
-        #self.options = OptionMap()
+        self.features = FeatureMap()
         self.pong = threading.Event()
-        self.ping_num = None # TODO: Make this a pong Event local instead of data member
+        self.ping_num = None
         self.pong_received = threading.Condition()
         self.auto_force = False
         self.in_force = False
@@ -183,6 +237,11 @@ class Engine(object):
     def on_line_received(self, buf):
         LOGGER.debug("%s >> %s", self.process, buf)
 
+        # Not too happy with this quasi-hack to prevent splitting within
+        # options' space-separated values
+        if buf.startswith("feature"):
+            return self._feature(buf[8:])
+
         command_and_args = buf.split()
         if not command_and_args:
             return
@@ -209,6 +268,48 @@ class Engine(object):
         with self.state_changed:
             self.state_changed.notify_all()
 
+    def _feature(self, features):
+        """
+        Does not conform to CECP spec regarding `done` and instead reads all
+        features atomically.
+        """
+        if features.startswith("option"):
+            features = features.replace("\"", "")
+            params = features.split("=")[1].split()
+            name = params[0]
+            type = params[1][1:]
+            min = None
+            max = None
+            var = []
+            if type == "combo":
+                choices = params[2:]
+                for choice in choices:
+                    if choice == "///":
+                        continue
+                    elif choice[0] == "*":
+                        default = choice[1:]
+                        var.append(choice[1:])
+                    else:
+                        var.append(choice)
+                print(var)
+                print(default)
+            else:
+                default = int(params[2])
+                min = int(params[3])
+                max = int(params[4])
+            option = Option(name, type, default, min, max, var)
+            self.features._features["option"][option.name] = option
+            return
+
+        features = features.split()
+        feature_map = [ feature.split("=") for feature in features ]
+        for (key, value) in feature_map:
+            value = value.strip("\"")
+            if key == "variant":
+                self.features._set_feature(key, value.split(","))
+            else:
+                self.features._set_feature(key, value)
+
     def _pong(self, pong_arg):
         try:
             pong_num = int(pong_arg)
@@ -346,30 +447,51 @@ class Engine(object):
         """
         Tell the engine not to ponder.
         """
-        self.pondering(False)
+        return self.pondering(False)
 
     def hard(self, async_callback=None):
         """
         Tell the engine to ponder.
         TODO: pondering not yet supported.
         """
-        self.pondering(True)
+        return self.pondering(True)
 
-    def post(self, async_callback=None):
+    def set_post(self, flag, async_callback=None):
         """
-        Command used to tell the engine to output it's analysis
+        Command used to tell the engine whether to output it's analysis or not.
+
+        :param flag: True or False to set post on or off.
 
         :return: Nothing
         """
         def command():
             with self.semaphore:
-                self.send_line("post")
+                if flag == True:
+                    self.send_line("post")
+                else:
+                    self.send_line("nopost")
 
                 if self.terminated.is_set():
                     raise EngineTerminatedException()
 
         return self._queue_command(command, async_callback)
 
+    def post(self, async_callback=None):
+        """
+        Command used to tell the engine to output it's analysis.
+
+        :return: Nothing
+        """
+        return self.set_post(True)
+
+    def nopost(self, async_callback=None):
+        """
+        Command used to tell the engine to not output it's analysis.
+
+        :return: Nothing
+        """
+        return self.set_post(False)
+
     def xboard(self, async_callback=None):
         """
         Tells the engine to use the XBoard interface.
@@ -384,7 +506,7 @@ class Engine(object):
         def command():
             with self.semaphore:
                 self.send_line("xboard")
-                self.send_line("protover 2") # TODO: Add option for this and parse input
+                self.send_line("protover 2")
 
                 if self.terminated.is_set():
                     raise EngineTerminatedException()
@@ -395,12 +517,46 @@ class Engine(object):
 
         return self._queue_command(command, async_callback)
 
+    def option(self, options, async_callback=None):
+        """
+        Set values for the engines available options.
+
+        :param options: A dictionary with option names as keys.
+
+        :return: Nothing
+        """
+        option_lines = []
+
+        for name, value in options.items():
+            # Building string manually to avoid spaces
+            option_string = "option " + name
+            option = self.features._features["option"][name]
+            has_value = option.type in \
+                    ("spin", "check", "combo", "string")
+            if has_value and value is not None:
+                value = str(value)
+                option_string += "=" + value
+                option_lines.append(option_string)
+            elif not has_value and value is None:
+                option_lines.append(option_string)
+
+        def command():
+            with self.semaphore:
+                with self.pong_received:
+                    for option_line in option_lines:
+                        self.send_line(option_line)
+
+                    if self.terminated.is_set():
+                        raise EngineTerminatedException()
+
+        return self._queue_command(command, async_callback)
+
     def new(self, async_callback=None):
         """
         Reset the board to the standard chess starting position.
         Set White on move.
         Leave force mode and set the engine to play Black.
-        Associate the engine's clock with Black and the opponent's clock
+        Associate the engines clock with Black and the opponent's clock
         with White.
         Reset clocks and time controls to the start of a new game.
         Use wall clock for time measurement.
@@ -428,7 +584,9 @@ class Engine(object):
         Set up a given board position.
 
         :param board: A *chess.Board*.
+
         :return: Nothing
+
         :raises: :exc:`~chess.engine.EngineStateException` if the engine is still
             calculating.
         """
@@ -454,12 +612,64 @@ class Engine(object):
 
         return self._queue_command(command, async_callback)
 
+    def memory(self, amount, async_callback=None):
+        """
+        Set the maximum memory of the engines hash/pawn/bitbase/etc tables.
+
+        :param amount: Maximum amount of memory to use in MegaBytes
+
+        :return: Nothing
+        """
+        if not self.features.supports("memory"):
+            raise EngineStateException("engine does not support the 'memory' feature")
+
+        with self.state_changed:
+            if not self.idle:
+                raise EngineStateException("memory command while engine is busy")
+
+        def command():
+            with self.semaphore:
+                self.send_line("memory " + str(amount))
+
+                if self.terminated.is_set():
+                    raise EngineTerminatedException
+
+        return self._queue_command(command, async_callback)
+
+    def cores(self, num, async_callback=None):
+        """
+        Set the maximum number of processors the engine is allowed to use.
+        That is, the number of search threads for an SMP engine.
+
+        :param num: The number of processors
+
+        :return: Nothing
+        """
+        if not self.features.supports("smp"):
+            raise EngineStateException("engine does not support the 'smp' feature")
+
+        with self.state_changed:
+            if not self.idle:
+                raise EngineStateException("cores command while engine is busy")
+
+        def command():
+            with self.semaphore:
+                self.send_line("cores " + str(num))
+
+                if self.terminated.is_set():
+                    raise EngineTerminatedException
+
+        return self._queue_command(command, async_callback)
+
     def playother(self, async_callback=None):
         """
         Set the engine to play the side whose turn it is NOT to move.
 
         :return: Nothing
         """
+        if not self.features.supports("playother"):
+            raise EngineStateException("engine does not support the 'playother' feature")
+
         with self.state_changed:
             if not self.idle:
                 raise EngineStateException("playother command while engine is busy")
@@ -518,12 +728,15 @@ class Engine(object):
 
     def time(self, time, async_callback=None):
         """
-        Synchronize the engine's clock with the total amount of time left.
+        Synchronize the engines clock with the total amount of time left.
 
         :param time: The total time left in centiseconds
 
         :return: Nothing
         """
+        if not self.features.supports("time"):
+            raise EngineStateException("engine does not support the 'time' feature")
+
         with self.state_changed:
             if not self.idle:
                 raise EngineStateException("time command while engine is busy")
@@ -598,6 +811,8 @@ class Engine(object):
         Tell the XBoard engine to enter force mode. That means
         the engine will not start thinking by itself unless a
         go() command is sent.
+
+        :return: Nothing
         """
         self.in_force = True
         def command():
@@ -615,6 +830,7 @@ class Engine(object):
         Start calculating on the current position.
 
         :return: the best move according to the engine.
+
         :raises: :exc:`~chess.engine.EngineStateException` if the engine is
             already calculating.
         """
@@ -659,6 +875,36 @@ class Engine(object):
 
         return self._queue_command(command, async_callback)
 
+    def stop(self, async_callback=None):
+        """
+        Stop calculating as soon as possible. The actual XBoard command is `?`.
+
+        :return: Nothing.
+        """
+        # Only send stop when the engine is actually searching.
+        def command():
+            with self.semaphore:
+                with self.state_changed:
+                    if not self.idle:
+                        self.search_started.wait()
+
+                    backoff = 0.5
+                    while not self.move_received.is_set() and not self.terminated.is_set():
+                        if self.idle:
+                            break
+                        else:
+                            self.send_line("?")
+                        self.move_received.wait(backoff)
+                        backoff *= 2
+
+                    self.idle = True
+                    self.state_changed.notify_all()
+
+                if self.terminated.is_set():
+                    raise EngineTerminatedException()
+
+        return self._queue_command(command, async_callback)
+
     def usermove(self, move, async_callback=None):
         """
         Tell the XBoard engine to make a move on it's internal
@@ -670,6 +916,10 @@ class Engine(object):
 
         :return: Nothing
         """
+        builder = []
+        if self.features.supports("usermove"):
+            builder.append("usermove")
+
         if self.auto_force:
             self.force()
         elif not self.in_force:
@@ -693,12 +943,10 @@ class Engine(object):
             except ValueError:
                 LOGGER.exception("exception parsing move")
 
-        builder = []
-        builder.append("usermove")
-        builder.append(move)
+        builder.append(str(move))
         def command():
             # Use the join(builder) once we parse usermove=1 feature
-            move_str = str(move)#" ".join(builder)
+            move_str = " ".join(builder)
             if self.in_force:
                 with self.semaphore:
                     self.send_line(move_str)
